@@ -28,10 +28,6 @@
 
 #include <map>
 
-#ifdef WANT_CLASS_INSTANTIATION_OF_MAP
-using namespace std;
-#endif
-
 #include "taglib.h"
 
 namespace TagLib {
@@ -123,7 +119,7 @@ namespace TagLib {
      *
      * \see isEmpty()
      */
-    uint size() const;
+    unsigned int size() const;
 
     /*!
      * Returns true if the map is empty.
